

export const index = 1;
let component_cache;
export const component = async () => component_cache ??= (await import('../entries/pages/_error.svelte.js')).default;
export const imports = ["_app/immutable/nodes/1.CQwkq4lO.js","_app/immutable/chunks/BsAB9Z30.js","_app/immutable/chunks/IHki7fMi.js","_app/immutable/chunks/Cw7RSa0z.js","_app/immutable/chunks/BY-rXZ0_.js"];
export const stylesheets = [];
export const fonts = [];
